pilas.escena.gestor.Gestor

Package pilas :: Package escena :: Module gestor :: Class Gestor |
[hide private]
[frames] | no frames]

# Class Gestor

source code

    object --+
             |
            Gestor

Clase que permite el control de las escenas en pilas.

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
limpiar(self) Elimina todas las escenas del gestor. | source code
cambiar_escena(self, escena) Define una escena unica y la inicializa. | source code
almacenar_escena(self, escena) Pausa la escena actualmente activa e inicializa la escena que le pasamos como parametro. | source code
recuperar_escena(self) Recupera la escena que fue Pausada mediante **almacenar_escena**. | source code
escena_actual(self) Retorna la escena actual o None si no hay escena definida. | source code
actualizar(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### cambiar_escena(self, escena) | source code
Define una escena unica y la inicializa. Las escenas que estuvieran apiladas se eliminan. :param escena: Escena a la que se quiere cambiar.

### almacenar_escena(self, escena) | source code
Pausa la escena actualmente activa e inicializa la escena que le pasamos como parametro. :param escena: Escena que deseamos que sea la activa.